@@ -11,6 +11,7 @@
 # under the License.
 
 import datetime
+import io
 import itertools
 import json
 import logging
@@ -21,7 +22,6 @@ import uuid
 from oslo_utils import encodeutils
 import requests
 import requests.auth
-import six
 from testtools import matchers
 
 from keystoneauth1 import adapter
@@ -383,11 +383,13 @@ class SessionTests(utils.TestCase):
         """Verify response body is only logged in specific content types.
 
         Response bodies are logged only when the response's Content-Type header
-        is set to application/json. This prevents us to get an unexpected
-        MemoryError when reading arbitrary responses, such as streams.
+        is set to application/json or text/plain. This prevents us to get an
+        unexpected MemoryError when reading arbitrary responses, such as
+        streams.
         """
-        OMITTED_BODY = ('Omitted, Content-Type is set to %s. Only '
-                        'application/json responses have their bodies logged.')
+        OMITTED_BODY = ('Omitted, Content-Type is set to %s. Only ' +
+                        ', '.join(client_session._LOG_CONTENT_TYPES) +
+                        ' responses have their bodies logged.')
         session = client_session.Session(verify=False)
 
         # Content-Type is not set
@@ -422,6 +424,23 @@ class SessionTests(utils.TestCase):
         self.assertNotIn(OMITTED_BODY % 'application/json; charset=UTF-8',
                          self.logger.output)
 
+        # Content-Type is set to text/plain
+        text = 'Error detected, unable to continue.'
+        self.stub_url('POST', text=text,
+                      headers={'Content-Type': 'text/plain'})
+        session.post(self.TEST_URL)
+        self.assertIn(text, self.logger.output)
+        self.assertNotIn(OMITTED_BODY % 'text/plain', self.logger.output)
+
+        # Content-Type is set to text/plain; charset=UTF-8
+        text = 'Error detected, unable to continue.'
+        self.stub_url('POST', text=text,
+                      headers={'Content-Type': 'text/plain; charset=UTF-8'})
+        session.post(self.TEST_URL)
+        self.assertIn(text, self.logger.output)
+        self.assertNotIn(OMITTED_BODY % 'text/plain; charset=UTF-8',
+                         self.logger.output)
+
     def test_logging_cacerts(self):
         path_to_certs = '/path/to/certs'
         session = client_session.Session(verify=path_to_certs)
@@ -848,6 +867,17 @@ class RedirectTests(utils.TestCase):
             self.assertEqual(resp.url, self.REDIRECT_CHAIN[i])
             self.assertEqual(resp.text, self.DEFAULT_REDIRECT_BODY)
 
+    def test_redirect_with_params(self):
+        params = {'foo': 'bar'}
+        session = client_session.Session(redirect=True)
+        # Note(knikolla): Setting complete_qs to True ensures that the mock
+        # will only match paths including all query strings.
+        self.setup_redirects(final_kwargs={'complete_qs': True})
+        resp = session.get(self.REDIRECT_CHAIN[0], params=params)
+        self.assertResponse(resp)
+        self.assertTrue(len(resp.history), len(self.REDIRECT_CHAIN))
+        self.assertQueryStringIs(None)
+
     def test_history_matches_requests(self):
         self.setup_redirects(status_code=301)
         session = client_session.Session(redirect=True)
@@ -868,6 +898,15 @@ class RedirectTests(utils.TestCase):
         resp = session.get(self.REDIRECT_CHAIN[-2])
         self.assertResponse(resp)
 
+    def test_req_id_redirect(self):
+        session = client_session.Session()
+        self.setup_redirects(status_code=302)
+        resp = session.get(self.REDIRECT_CHAIN[0],
+                           headers={'x-openstack-request-id': 'req-1234-5678'})
+        self.assertResponse(resp)
+        self.assertRequestHeaderEqual('x-openstack-request-id',
+                                      'req-1234-5678')
+
 
 class AuthPlugin(plugin.BaseAuthPlugin):
     """Very simple debug authentication plugin.
@@ -1239,8 +1278,8 @@ class SessionAuthTests(utils.TestCase):
         logger.setLevel(logging.DEBUG)
         logger.propagate = False
 
-        io = six.StringIO()
-        handler = logging.StreamHandler(io)
+        string_io = io.StringIO()
+        handler = logging.StreamHandler(string_io)
         logger.addHandler(handler)
 
         auth = AuthPlugin()
@@ -1254,7 +1293,7 @@ class SessionAuthTests(utils.TestCase):
         resp = sess.get(self.TEST_URL, logger=logger)
 
         self.assertEqual(response, resp.json())
-        output = io.getvalue()
+        output = string_io.getvalue()
 
         self.assertIn(self.TEST_URL, output)
         self.assertIn(list(response.keys())[0], output)
@@ -1270,14 +1309,14 @@ class SessionAuthTests(utils.TestCase):
             logger = logging.getLogger(logger_name)
             logger.setLevel(logging.DEBUG)
 
-            io = six.StringIO()
-            handler = logging.StreamHandler(io)
+            string_io = io.StringIO()
+            handler = logging.StreamHandler(string_io)
             logger.addHandler(handler)
-            return io
+            return string_io
 
-        io = {}
+        io_dict = {}
         for name in ('request', 'body', 'response', 'request-id'):
-            io[name] = get_logger_io(name)
+            io_dict[name] = get_logger_io(name)
 
         auth = AuthPlugin()
         sess = client_session.Session(auth=auth, split_loggers=True)
@@ -1303,10 +1342,10 @@ class SessionAuthTests(utils.TestCase):
 
         self.assertEqual(response, resp.json())
 
-        request_output = io['request'].getvalue().strip()
-        response_output = io['response'].getvalue().strip()
-        body_output = io['body'].getvalue().strip()
-        id_output = io['request-id'].getvalue().strip()
+        request_output = io_dict['request'].getvalue().strip()
+        response_output = io_dict['response'].getvalue().strip()
+        body_output = io_dict['body'].getvalue().strip()
+        id_output = io_dict['request-id'].getvalue().strip()
 
         self.assertIn('curl -g -i -X GET {url}'.format(url=self.TEST_URL),
                       request_output)
@@ -1588,8 +1627,8 @@ class AdapterTest(utils.TestCase):
         logger.setLevel(logging.DEBUG)
         logger.propagate = False
 
-        io = six.StringIO()
-        handler = logging.StreamHandler(io)
+        string_io = io.StringIO()
+        handler = logging.StreamHandler(string_io)
         logger.addHandler(handler)
 
         auth = AuthPlugin()
@@ -1604,7 +1643,7 @@ class AdapterTest(utils.TestCase):
         resp = adpt.get(self.TEST_URL, logger=logger)
 
         self.assertEqual(response, resp.json())
-        output = io.getvalue()
+        output = string_io.getvalue()
 
         self.assertIn(self.TEST_URL, output)
         self.assertIn(list(response.keys())[0], output)
